function  plotfp(f,numx,numy,redline,linewidth,scolor,edgecolor)
%Creates a surfplot of the data f=[X;Y;Z]

%Input: f=[X;Y;Z] is the grid data for a surface

%All the other inputs are optional
%numx is the number of parameter x-coordinate strips to color white
%  cannot exceed the number of y points in the grid
%numy is the number of y-coordinate strips
%  cannot exceed the number of x points in the grid

%if "redline" is greater than zero, then a strip around the x-axis
%of width "redline" is colored red
%scolor is the main surface color
%edgecolor is the color of the coordinate strips

fdims=size(f);  xpoints=fdims(1)/3; ypoints=fdims(2);

if nargin<7
    edgecolor=[0.7,0.8,0.9];
end
if nargin<6
    scolor=[0.04,0.52,0.78];
end
if nargin<5
    linewidth=1;
end
if nargin<4
    redline=0;
end      
if nargin<3
    numy=min(10,xpoints);
end
if nargin<2
    numx=min(10,ypoints);
end

if numx+numy>0   
  colormap([scolor;edgecolor]);
else
    colormap([scolor]);
end
C=zeros(xpoints,ypoints);
if numx>0
  if numx==1
    xcurves=1;
  else
    xstep=round((ypoints-2)/(numx(1)-1));
    xcurves=[1,xstep+1:xstep:((numx(1)-1)*xstep),ypoints-1];
  end
    for j=1:floor(numx(1)/2)
      C(1:xpoints,xcurves(j):xcurves(j)+linewidth-1)=1;
    end
  for j=floor(numx(1)/2)+1:numx(1)
      C(1:xpoints,xcurves(j)-linewidth+1:xcurves(j))=1;
  end
end

if numy>0
  ystep=round((xpoints-2)/(numy(1)-1));
  if numy==1
    ycurves=1;
  else
    ycurves=[1,ystep+1:ystep:((numy(1)-1)*ystep),xpoints-1];
  end
  for j=1:floor(numy(1)/2)
        C(ycurves(j):ycurves(j)+linewidth-1,:)=1;
  end
  for j=floor(numy(1)/2)+1:numy(1)
      C(ycurves(j)-linewidth+1:ycurves(j),:)=1;
  end
end

 if nargin>3
        if redline>0
             redline=[floor((ypoints+1)/2),redline,1,0,0];
             if numx+numy>0
               colormap([scolor;1 0 0;edgecolor]);
             else
                 colormap([scolor;1 0 0]); 
             end
             C(:,max(1,redline(1)-redline(2)):min(ypoints,redline(1)+redline(2)))=0.5*ones(xpoints,1+min(ypoints,redline(1)+redline(2))-max(1,redline(1)-redline(2)));
        end
end
   
                
surf(f(1:xpoints, :), f(xpoints+1: 2*xpoints, :),  f(2*xpoints+1: 3*xpoints, :),C, 'Clipping','off','EdgeAlpha',0,'FaceLighting','gouraud',...
    'DiffuseStrength',0.9,'SpecularExponent',20.0,'SpecularStrength',0.3,'AmbientStrength',0.3);
daspect([1,1,1])
  grid off
 axis off
  hold off
end

