function X=sing(b,c)
%The potential for a spherical surface with a singular curve defined by 
%two functions b and c. For use with the function "k1surfX.m"
%(c is the curvature function of the normal to the solution surface
% along the curve y=0, and x is the arc length parameter for this normal).

%Input: b and c are function handles for analytic functions of 1 variable
%The solution surface will have a singular curve along y=0.  For a non-degenerate
%singularity, c is assumed non-vanishing.  Given this, the singularity
%at (0,0) is:
% - a cone point if and only if b=@(t)0  the zero function
% - a swallowtail if and only if b(0)=0 and b'(0) is non-zero
% - a cuspidal butterfly if and only if b(0)=b'(0)=0 and b''(0) is non-zero
% - a cuspidal edge if b(0) is nonzero

X=@(z,h)(1/4)*[0,-1-1i*b(z),1i*2*c(z),-1+1i*b(z),0,0;0,0,1+1i*b(z),-1i*2*c(z),1-1i*b(z),0];
end